#ifndef SETTINGS_H
#define SETTINGS_H

#include <QSettings>

namespace Settings
{

static QMap<QString, QVariant> defaults = {
    // General info
    {"General/UI_scale", "100"},
    {"General/CurrentInitStage", "0"},
    {"General/MicroUpdates", "Disabled"},

    // Lotro Manager
    {"Lotro/game_path", "none"},
    {"Lotro/original_locale", "English"},
    {"Lotro/skip_raw_download", "True"},
    {"Lotro/no_splash_screen", "True"},

    // Databases download settings
    {"DatabaseDownload/sound", "Disabled"},
    {"DatabaseDownload/text", "Disabled"},
    {"DatabaseDownload/image", "Disabled"},
    {"DatabaseDownload/loadscreen", "Disabled"},
    {"DatabaseDownload/texture", "Disabled"},
    {"DatabaseDownload/font", "Disabled"},
    {"DatabaseDownload/video", "Disabled"},

    // Databases applied status
    {"DatabaseApplied/sound", "False"},
    {"DatabaseApplied/text", "False"},
    {"DatabaseApplied/image", "False"},
    {"DatabaseApplied/loadscreen", "False"},
    {"DatabaseApplied/texture", "False"},
    {"DatabaseApplied/font", "False"},
    {"DatabaseApplied/video", "False"},

    // Databases downloaded paths
    {"DatabasePath/sound", "none"},
    {"DatabasePath/text", "none"},
    {"DatabasePath/image", "none"},
    {"DatabasePath/loadscreen", "none"},
    {"DatabasePath/texture", "none"},
    {"DatabasePath/font", "none"},
    {"DatabasePath/video", "none"},

    // Databases download date
    {"DatabaseDownloadDate/sound", "none"},
    {"DatabaseDownloadDate/text", "none"},
    {"DatabaseDownloadDate/image", "none"},
    {"DatabaseDownloadDate/loadscreen", "none"},
    {"DatabaseDownloadDate/texture", "none"},
    {"DatabaseDownloadDate/font", "none"},
    {"DatabaseDownloadDate/video", "none"},

    // Localisation components
    {"Components/fonts", "Disabled"},
    {"Components/texts_main", "Disabled"},
    {"Components/texts_items", "Disabled"},
    {"Components/texts_emotes", "Disabled"},
    {"Components/maps", "Disabled"},
    {"Components/loadscreens", "Disabled"},
    {"Components/sounds", "Disabled"},
    {"Components/videos", "Disabled"},

    // Network
    {"Network/site_url", "http://translate.lotros.ru/"},
    {"Network/forum_url", "http://lotros.ru/"},
    {"Network/discord_url", "https://discord.gg/j25MdKR"},
    {"Network/add_report_url", "http://translate.lotros.ru/bugs/add"},
    {"Network/donate_url", "http://translate.lotros.ru/donate"},
    {"Network/game_servers_status", "http://translate.lotros.ru/servers.txt"},
    {"Network/game_servers_message", "http://translate.lotros.ru/profmessage.txt"},
    {"Network/weekly_code_url", "http://translate.lotros.ru/coupon.txt"},
    {"Network/news_list_url", "http://translate.lotros.ru/groupware/launcher_news/30/1"}
};

static void setDefaultSettings()
{
    QSettings settings;
    foreach (QString key, defaults.keys()) {
        settings.setValue(key, defaults[key]);
    }
}

static QVariant getValue(QString key) {
    Q_ASSERT(defaults.contains(key)); // any required key should be pre-defined in defaults
    QSettings settings;
    return settings.value(key, defaults[key]);
}

static void setValue(QString key, QVariant value) {
    QSettings settings;
    settings.setValue(key, value);
}


}

#endif // SETTINGS_H
